@@ -21,15 +21,19 @@
 This file implements test cases for compose sequences.
 '''
 
+from typing import Optional
 import sys
+import os
+import shutil
+import tempfile
 import logging
 import locale
 import unittest
 
 # pylint: disable=wrong-import-position
-from gi import require_version # type: ignore
+from gi import require_version
 require_version('IBus', '1.0')
-from gi.repository import IBus # type: ignore
+from gi.repository import IBus
 # pylint: enable=wrong-import-position
 
 LOGGER = logging.getLogger('ibus-typing-booster')
@@ -44,6 +48,31 @@ import testutils # pylint: disable=import-error
 # pylint: disable=missing-class-docstring
 
 class ComposeSequencesTestCase(unittest.TestCase):
+    _tempdir: Optional[tempfile.TemporaryDirectory] = None # type: ignore[type-arg]
+    # Python 3.12+: _tempdir: Optional[tempfile.TemporaryDirectory[str]] = None
+    _orig_xcomposefile: Optional[str] = None
+
+    @classmethod
+    def setUpClass(cls) -> None:
+        # Avoid failing test cases because of stuff in the users '~/.XCompose' file.
+        cls._tempdir = tempfile.TemporaryDirectory() # pylint: disable=consider-using-with
+        cls._orig_xcomposefile = os.environ.pop('XCOMPOSEFILE', None)
+        os.environ['XCOMPOSEFILE'] = os.path.join(cls._tempdir.name, 'XCompose')
+        shutil.copy('XCompose', cls._tempdir.name)
+        tempdir_files = [os.path.join(cls._tempdir.name, basename)
+                         for basename in os.listdir(cls._tempdir.name)]
+        for path in tempdir_files:
+            LOGGER.info('Temporary directory content: %r', path)
+
+    @classmethod
+    def tearDownClass(cls) -> None:
+        if cls._orig_xcomposefile is not None:
+            os.environ['XCOMPOSEFILE'] = cls._orig_xcomposefile
+        else:
+            _value = os.environ.pop('XCOMPOSEFILE', None)
+        if cls._tempdir is not None:
+            cls._tempdir.cleanup()
+
     def setUp(self) -> None:
         locale.setlocale(locale.LC_CTYPE, 'en_US.UTF-8')
         self._compose_sequences = itb_util.ComposeSequences()
@@ -296,6 +325,9 @@ class ComposeSequencesTestCase(unittest.TestCase):
 
         This is used in the fr(bepo_afnor) keyboard layout, see also:
 
+        Layout: https://bepo.fr/wiki/Version_1.1rc2
+        Normalization: https://normalisation.afnor.org/actualites/faq-clavier-francais/
+
         https://github.com/ibus/ibus/issues/2748
         https://gitlab.gnome.org/GNOME/gtk/-/issues/7386
         https://raw.githubusercontent.com/andrewathalye/bepo-xcompose-fix/main/XCompose
@@ -310,22 +342,41 @@ class ComposeSequencesTestCase(unittest.TestCase):
             '<UFDD7> <s>', '∫')
         self.assertEqual('∫', self._compose_sequences.compose([0x0100fdd7, IBus.KEY_s]))
         # pylint: enable=protected-access
+        self.assertEqual(
+            self._compose_sequences.preedit_representation(
+                [0x0100fdd4]),
+            'ß' # U+00DF LATIN SMALL LETTER SHARP S
+        )
         self.assertEqual(
             self._compose_sequences.preedit_representation(
                 [0x0100fdd5]),
-            '·')
+            'ᵉ' # U+1D49 MODIFIER LETTER SMALL E
+        )
         self.assertEqual(
             self._compose_sequences.preedit_representation(
                 [0x0100fdd7]),
-            '·')
+            '∞' # U+221E INFINITY
+        )
+        self.assertEqual(
+            self._compose_sequences.preedit_representation(
+                [0x0100fdd8]),
+            '―' # U+2015 HORIZONTAL BAR
+        )
         self.assertEqual(
             self._compose_sequences.preedit_representation(
                 [0x0100fdd5, 0x0100fdd7]),
-            '·')
+            'ᵉ∞' # U+1D49 MODIFIER LETTER SMALL E U+221E INFINITY
+        )
         self.assertEqual(
             self._compose_sequences.preedit_representation(
                 [IBus.KEY_Multi_key, 0x0100fdd5, 0x0100fdd7]),
-            '··')
+            'ᵉ∞' # U+1D49 MODIFIER LETTER SMALL E U+221E INFINITY
+        )
+        self.assertEqual(
+            self._compose_sequences.preedit_representation(
+                [IBus.KEY_Multi_key, 0x0100fdd5, 0x0100fdd7, IBus.KEY_Multi_key]),
+            'ᵉ∞·' # U+1D49 MODIFIER LETTER SMALL E U+221E INFINITY U+00B7 MIDDLE DOT
+        )
 
     def test_preedit_representations(self) -> None:
         self.assertEqual(
